changeset 755:73320fa3a318 draft

Yet another new tests added into BitBltUsingBgColor.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 02 Sep 2015 11:13:28 +0200
parents 7494d15503ab
children 3ea01f17c392
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 37 insertions(+), 32 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Sep 01 11:24:08 2015 +0200
+++ b/ChangeLog	Wed Sep 02 11:13:28 2015 +0200
@@ -1,3 +1,8 @@
+2015-09-02  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Yet another new tests added into BitBltUsingBgColor.
+
 2015-09-01  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Sep 01 11:24:08 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Sep 02 11:13:28 2015 +0200
@@ -10636,7 +10636,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10645,13 +10645,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -10660,13 +10660,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -10675,13 +10675,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -10690,13 +10690,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -10705,9 +10705,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.black);
+    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
     }
 
     /**
@@ -10636,7 +10636,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
      * Background color is set to Color.red.
      *